@@ -1,10 +1,5 @@
 ##
-# Copyright 2009-2012 Ghent University
-# Copyright 2009-2012 Stijn De Weirdt
-# Copyright 2010 Dries Verdegem
-# Copyright 2010-2012 Kenneth Hoste
-# Copyright 2011 Pieter De Baets
-# Copyright 2011-2012 Jens Timmerman
+# Copyright 2009-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -29,13 +24,21 @@
 ##
 """
 EasyBuild support for CPLEX, implemented as an easyblock
+
+@author: Stijn De Weirdt (Ghent University)
+@author: Dries Verdegem (Ghent University)
+@author: Kenneth Hoste (Ghent University)
+@author: Pieter De Baets (Ghent University)
+@author: Jens Timmerman (Ghent University)
 """
 import glob
 import os
+import shutil
 import stat
 
 import easybuild.tools.environment as env
 from easybuild.easyblocks.generic.binary import Binary
+from easybuild.framework.easyconfig import CUSTOM
 from easybuild.tools.filetools import run_cmd_qa
 
 
@@ -47,43 +50,63 @@ class EB_CPLEX(Binary):
 
     def __init__(self, *args, **kwargs):
         """Initialize CPLEX-specific variables."""
-
         super(EB_CPLEX, self).__init__(*args, **kwargs)
         self.bindir = None
 
+    @staticmethod
+    def extra_options():
+        extra_vars = [
+            # staged install via a tmp dir can help with the hard (potentially faulty) check on available disk space
+            ('staged_install', [False, "Should the installation should be staged via a temporary dir?", CUSTOM]),
+        ]
+        return Binary.extra_options(extra_vars)
+
     def install_step(self):
         """CPLEX has an interactive installer, so use Q&A"""
 
         tmpdir = os.path.join(self.builddir, 'tmp')
+        stagedir = os.path.join(self.builddir, 'staged')
         try:
             os.chdir(self.builddir)
             os.makedirs(tmpdir)
-
+            os.makedirs(stagedir)
         except OSError, err:
             self.log.exception("Failed to prepare for installation: %s" % err)
 
         env.setvar('IATEMPDIR', tmpdir)
         dst = os.path.join(self.builddir, self.src[0]['name'])
 
-        # Run the source
         cmd = "%s -i console" % dst
 
+        install_target = self.installdir
+        if self.cfg['staged_install']:
+            install_target = stagedir
+
         qanda = {
-                 "PRESS <ENTER> TO CONTINUE:":"",
-                 'Press Enter to continue viewing the license agreement, or enter' \
-                 ' "1" to accept the agreement, "2" to decline it, "3" to print it,' \
-                 ' or "99" to go back to the previous screen.:':'1',
-                 'ENTER AN ABSOLUTE PATH, OR PRESS <ENTER> TO ACCEPT THE DEFAULT :':self.installdir,
-                 'IS THIS CORRECT? (Y/N):':'y',
-                 'PRESS <ENTER> TO INSTALL:':"",
-                 "PRESS <ENTER> TO EXIT THE INSTALLER:":"",
-                 "CHOOSE LOCALE BY NUMBER:":"",
-                 "Choose Instance Management Option:":""
-                 }
+            "PRESS <ENTER> TO CONTINUE:": '',
+            'Press Enter to continue viewing the license agreement, or enter' \
+            ' "1" to accept the agreement, "2" to decline it, "3" to print it,' \
+            ' or "99" to go back to the previous screen.:': '1',
+            'ENTER AN ABSOLUTE PATH, OR PRESS <ENTER> TO ACCEPT THE DEFAULT :': install_target,
+            'IS THIS CORRECT? (Y/N):': 'y',
+            'PRESS <ENTER> TO INSTALL:': '',
+            "PRESS <ENTER> TO EXIT THE INSTALLER:": '',
+            "CHOOSE LOCALE BY NUMBER:": '',
+            "Choose Instance Management Option:": '',
+        }
         noqanda = [r'Installing\.\.\..*\n.*------.*\n\n.*============.*\n.*$']
 
         run_cmd_qa(cmd, qanda, no_qa=noqanda, log_all=True, simple=True)
 
+        if self.cfg['staged_install']:
+            # move staged installation to actual install dir
+            try:
+                # copytree expects target directory to not exist yet
+                shutil.rmtree(self.installdir)
+                shutil.copytree(stagedir, self.installdir)
+            except OSError, err:
+                self.log.error("Failed to move staged install from %s to %s: %s" % (stagedir, self.installdir, err))
+
         try:
             os.chmod(self.installdir, stat.S_IRWXU | stat.S_IXOTH | stat.S_IXGRP | stat.S_IROTH | stat.S_IRGRP)
         except OSError, err:
@@ -113,8 +136,9 @@ class EB_CPLEX(Binary):
     def sanity_check_step(self):
         """Custom sanity check for CPLEX"""
 
-        custom_paths = {'files':["%s/%s" % (self.bindir, x) for x in ["convert", "cplex", "cplexamp"]],
-                        'dirs':[]
-                       }
+        custom_paths = {
+            'files':["%s/%s" % (self.bindir, x) for x in ["convert", "cplex", "cplexamp"]],
+            'dirs':[],
+        }
 
         super(EB_CPLEX, self).sanity_check_step(custom_paths=custom_paths)
