@@ -150,7 +150,7 @@ class PythonPackage(ExtensionEasyBlock):
     def build_step(self):
         """Build Python package using setup.py"""
 
-        cmd = "python setup.py build %s" % self.cfg['makeopts']
+        cmd = "python setup.py build %s" % self.cfg['buildopts']
         run_cmd(cmd, log_all=True, simple=True)
 
     def test_step(self):
